dovecot-2.0: Fixing my english: s/non-?existing/nonexistent/

dovecot at dovecot.org dovecot at dovecot.org
Thu Jul 22 19:06:20 EEST 2010


details:   http://hg.dovecot.org/dovecot-2.0/rev/05031751cc21
changeset: 11887:05031751cc21
user:      Timo Sirainen <tss at iki.fi>
date:      Thu Jul 22 17:06:16 2010 +0100
description:
Fixing my english: s/non-?existing/nonexistent/

diffstat:

 doc/example-config/conf.d/15-lda.conf                    |  2 +-
 src/auth/auth-master-connection.c                        |  2 +-
 src/auth/db-passwd-file.c                                |  2 +-
 src/lib-dict/dict.h                                      |  2 +-
 src/lib-storage/index/dbox-multi/mdbox-storage-rebuild.c |  2 +-
 src/lib-storage/index/index-mail-headers.c               |  4 ++--
 src/lib-storage/index/index-mail.c                       |  2 +-
 src/lib-storage/index/index-search.c                     |  2 +-
 src/lib-storage/index/index-thread.c                     |  2 +-
 src/lib-storage/index/maildir/maildir-keywords.h         |  2 +-
 src/lib-storage/index/maildir/maildir-util.c             |  2 +-
 src/lib-storage/index/shared/shared-storage.c            |  6 +++---
 src/lib-storage/list/mailbox-list-maildir.c              |  2 +-
 src/lib-storage/mail-storage.h                           |  2 +-
 src/lib-storage/mailbox-list.c                           |  2 +-
 src/plugins/fts-solr/fts-backend-solr.c                  |  2 +-
 src/plugins/virtual/virtual-sync.c                       |  4 ++--
 17 files changed, 21 insertions(+), 21 deletions(-)

diffs (240 lines):

diff -r 93aee2609041 -r 05031751cc21 doc/example-config/conf.d/15-lda.conf
--- a/doc/example-config/conf.d/15-lda.conf	Thu Jul 22 16:46:48 2010 +0100
+++ b/doc/example-config/conf.d/15-lda.conf	Thu Jul 22 17:06:16 2010 +0100
@@ -28,7 +28,7 @@
 # Delimiter character between local-part and detail in email address.
 #recipient_delimiter = +
 
-# Should saving a mail to a non-existing mailbox automatically create it?
+# Should saving a mail to a nonexistent mailbox automatically create it?
 #lda_mailbox_autocreate = no
 
 # Should automatically created mailboxes be also automatically subscribed?
diff -r 93aee2609041 -r 05031751cc21 src/auth/auth-master-connection.c
--- a/src/auth/auth-master-connection.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/auth/auth-master-connection.c	Thu Jul 22 17:06:16 2010 +0100
@@ -91,7 +91,7 @@
 
 	client_conn = auth_client_connection_lookup(client_pid);
 	if (client_conn == NULL) {
-		i_error("Master requested auth for nonexisting client %u",
+		i_error("Master requested auth for nonexistent client %u",
 			client_pid);
 		(void)o_stream_send_str(conn->output,
 					t_strdup_printf("FAIL\t%u\n", id));
diff -r 93aee2609041 -r 05031751cc21 src/auth/db-passwd-file.c
--- a/src/auth/db-passwd-file.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/auth/db-passwd-file.c	Thu Jul 22 17:06:16 2010 +0100
@@ -245,7 +245,7 @@
 
 	if (stat(pw->path, &st) < 0) {
 		/* with variables don't give hard errors, or errors about
-		   nonexisting files */
+		   nonexistent files */
 		if (errno == EACCES) {
 			i_error("passwd-file %s: %s", pw->path,
 				eacces_error_get("stat", pw->path));
diff -r 93aee2609041 -r 05031751cc21 src/lib-dict/dict.h
--- a/src/lib-dict/dict.h	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-dict/dict.h	Thu Jul 22 17:06:16 2010 +0100
@@ -59,7 +59,7 @@
 /* Start a new dictionary transaction. */
 struct dict_transaction_context *dict_transaction_begin(struct dict *dict);
 /* Commit the transaction. Returns 1 if ok, 0 if dict_atomic_inc() was used
-   on a non-existing key, -1 if failed. */
+   on a nonexistent key, -1 if failed. */
 int dict_transaction_commit(struct dict_transaction_context **ctx);
 /* Commit the transaction, but don't wait to see if it finishes successfully.
    If callback isn't NULL, it's called eventually. If it's not called by the
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/index/dbox-multi/mdbox-storage-rebuild.c
--- a/src/lib-storage/index/dbox-multi/mdbox-storage-rebuild.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/index/dbox-multi/mdbox-storage-rebuild.c	Thu Jul 22 17:06:16 2010 +0100
@@ -338,7 +338,7 @@
 		pos = bsearch(&search_msgp, msgs, count, sizeof(*msgs),
 			      mdbox_rebuild_msg_offset_cmp);
 		if (pos == NULL || (*pos)->map_uid != 0) {
-			/* map record points to non-existing or
+			/* map record points to nonexistent or
 			   a duplicate message. */
 			mail_index_expunge(ctx->atomic->sync_trans, seq);
 		} else {
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/index/index-mail-headers.c
--- a/src/lib-storage/index/index-mail-headers.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/index/index-mail-headers.c	Thu Jul 22 17:06:16 2010 +0100
@@ -340,7 +340,7 @@
 		str_append_n(mail->header_data, hdr->middle, hdr->middle_len);
 
 		/* remember that we saw this header so we don't add it to
-		   cache as nonexisting. */
+		   cache as nonexistent. */
 		match[field_idx] |= HEADER_MATCH_FLAG_FOUND;
 	}
 	str_append_n(mail->header_data, hdr->value, hdr->value_len);
@@ -641,7 +641,7 @@
 	data = buffer_get_modifiable_data(dest, &len);
 
 	if (len == 0) {
-		/* cached as non-existing. */
+		/* cached as nonexistent. */
 		*value_r = p_new(mail->data_pool, const char *, 1);
 		return 0;
 	}
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/index/index-mail.c
--- a/src/lib-storage/index/index-mail.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/index/index-mail.c	Thu Jul 22 17:06:16 2010 +0100
@@ -1129,7 +1129,7 @@
 	/* If uid == 0 but seq != 0, we came here from saving a (non-mbox)
 	   message. If that happens, don't bother checking if anything should
 	   be cached since it was already checked. Also by now the transaction
-	   may have already been rollbacked and seq point to a non-existing
+	   may have already been rollbacked and seq point to a nonexistent
 	   message. */
 	if (mail->mail.mail.uid != 0) {
 		index_mail_cache_sizes(mail);
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/index/index-search.c
--- a/src/lib-storage/index/index-search.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/index/index-search.c	Thu Jul 22 17:06:16 2010 +0100
@@ -736,7 +736,7 @@
 			   (e.g. with count+1:* we still want to include it) */
 			seq_range_array_add(seqset, 0, messages_count);
 		}
-		/* remove all non-existing messages */
+		/* remove all nonexistent messages */
 		seq_range_array_remove_range(seqset, messages_count + 1,
 					     (uint32_t)-1);
 	}
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/index/index-thread.c
--- a/src/lib-storage/index/index-thread.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/index/index-thread.c	Thu Jul 22 17:06:16 2010 +0100
@@ -232,7 +232,7 @@
 			return -1;
 
 		/* Message is expunged. Instead of failing the entire THREAD
-		   command, just treat the header as non-existing. */
+		   command, just treat the header as nonexistent. */
 		*value_r = NULL;
 	}
 	return 0;
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/index/maildir/maildir-keywords.h
--- a/src/lib-storage/index/maildir/maildir-keywords.h	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/index/maildir/maildir-keywords.h	Thu Jul 22 17:06:16 2010 +0100
@@ -19,7 +19,7 @@
 struct maildir_keywords_sync_ctx *
 maildir_keywords_sync_init(struct maildir_keywords *mk,
 			   struct mail_index *index);
-/* Don't try to add any nonexisting keywords */
+/* Don't try to add any nonexistent keywords */
 struct maildir_keywords_sync_ctx *
 maildir_keywords_sync_init_readonly(struct maildir_keywords *mk,
 				    struct mail_index *index);
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/index/maildir/maildir-util.c
--- a/src/lib-storage/index/maildir/maildir-util.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/index/maildir/maildir-util.c	Thu Jul 22 17:06:16 2010 +0100
@@ -92,7 +92,7 @@
 	struct stat st;
 
 	if (lstat(path, &st) == 0 && (st.st_mode & S_IFLNK) != 0) {
-		/* most likely a symlink pointing to a non-existing file */
+		/* most likely a symlink pointing to a nonexistent file */
 		mail_storage_set_critical(&mbox->storage->storage,
 			"Maildir: Symlink destination doesn't exist: %s", path);
 		return -2;
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/list/mailbox-list-maildir.c
--- a/src/lib-storage/list/mailbox-list-maildir.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/list/mailbox-list-maildir.c	Thu Jul 22 17:06:16 2010 +0100
@@ -566,7 +566,7 @@
 	int ret;
         bool found;
 
-	/* NOTE: it's possible to rename a nonexisting mailbox which has
+	/* NOTE: it's possible to rename a nonexistent mailbox which has
 	   children. In that case we should ignore the rename() error. */
 	oldpath = mailbox_list_get_path(oldlist, oldname,
 					MAILBOX_LIST_PATH_TYPE_MAILBOX);
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/mail-storage.h
--- a/src/lib-storage/mail-storage.h	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/mail-storage.h	Thu Jul 22 17:06:16 2010 +0100
@@ -337,7 +337,7 @@
 void mailbox_free(struct mailbox **box);
 
 /* Create a mailbox. Returns failure if it already exists. Mailbox name is
-   allowed to contain multiple new non-existing hierarchy levels. If directory
+   allowed to contain multiple new nonexistent hierarchy levels. If directory
    is TRUE, the mailbox should be created so that it can contain children. The
    mailbox itself doesn't have to be created as long as it shows up in LIST.
    If update is non-NULL, its contents are used to set initial mailbox
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/mailbox-list.c
--- a/src/lib-storage/mailbox-list.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/mailbox-list.c	Thu Jul 22 17:06:16 2010 +0100
@@ -1156,7 +1156,7 @@
 		return -1;
 
 	/* subscriptions are about names, not about mailboxes. it's possible
-	   to have a subscription to non-existing mailbox. renames also don't
+	   to have a subscription to nonexistent mailbox. renames also don't
 	   change subscriptions. so instead of using actual GUIDs, we'll use
 	   hash of the name. */
 	mailbox_name_get_sha128(name, guid);
diff -r 93aee2609041 -r 05031751cc21 src/plugins/fts-solr/fts-backend-solr.c
--- a/src/plugins/fts-solr/fts-backend-solr.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/plugins/fts-solr/fts-backend-solr.c	Thu Jul 22 17:06:16 2010 +0100
@@ -182,7 +182,7 @@
 						   set->default_ns_prefix);
 		if (backend->default_ns == NULL) {
 			i_fatal("fts_solr: default_ns setting points to "
-				"nonexisting namespace");
+				"nonexistent namespace");
 		}
 	} else {
 		backend->default_ns =
diff -r 93aee2609041 -r 05031751cc21 src/plugins/virtual/virtual-sync.c
--- a/src/plugins/virtual/virtual-sync.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/plugins/virtual/virtual-sync.c	Thu Jul 22 17:06:16 2010 +0100
@@ -774,7 +774,7 @@
 	seq_range_array_remove_seq_range(added_uids, &drop_uids);
 }
 
-static void virtual_sync_drop_nonexisting(struct virtual_backend_box *bbox,
+static void virtual_sync_drop_nonexistent(struct virtual_backend_box *bbox,
 					  ARRAY_TYPE(seq_range) *removed_uids)
 {
 	ARRAY_TYPE(seq_range) drop_uids;
@@ -835,7 +835,7 @@
 	}
 
 	virtual_sync_drop_existing(bbox, &added_uids);
-	virtual_sync_drop_nonexisting(bbox, &removed_uids);
+	virtual_sync_drop_nonexistent(bbox, &removed_uids);
 
 	/* if any of the pending removes came back, we don't want to expunge
 	   them anymore. also since they already exist, remove them from


More information about the dovecot-cvs mailing list
diff -r 93aee2609041 -r 05031751cc21 src/lib-storage/index/shared/shared-storage.c
--- a/src/lib-storage/index/shared/shared-storage.c	Thu Jul 22 16:46:48 2010 +0100
+++ b/src/lib-storage/index/shared/shared-storage.c	Thu Jul 22 17:06:16 2010 +0100
@@ -95,7 +95,7 @@
 }
 
 static void
-get_nonexisting_user_location(struct shared_storage *storage,
+get_nonexistent_user_location(struct shared_storage *storage,
 			      const char *username, string_t *location)
 {
 	/* user wasn't found. we'll still need to create the storage
@@ -103,7 +103,7 @@
 	str_append(location, storage->storage_class->name);
 	str_append_c(location, ':');
 
 	/* use a reachable but non-existing path as the mail root directory */
 	str_append(location, storage->storage.user->set->base_dir);
 	str_append(location, "/user-not-found/");
 	str_append(location, username);
@@ -265,7 +265,7 @@
 	if (ret > 0)
 		var_expand(location, storage->location, tab);
 	else {
-		get_nonexisting_user_location(storage, userdomain, location);
+		get_nonexistent_user_location(storage, userdomain, location);
 		new_ns->flags |= NAMESPACE_FLAG_UNUSABLE;
 	}
 
@@ -103,7 +103,7 @@
 	str_append_c(location, ':');
 
-	/* use a reachable but non-existing path as the mail root directory */
+	/* use a reachable but nonexistent path as the mail root directory */
 	str_append(location, storage->storage.user->set->base_dir);
 	str_append(location, "/user-not-found/");